---
title: 'Pambda.com: Choose a file format for your writings'
author: 'Joseph Lucas'
date: '2021-11-18'
description: 'For each file format (markdown, docx, odt and html) compatible word processors are compared (Microsoft Word, Zettlr, Open Office, etc).'
keywords: 'Pambda, Pambda.com, File Format, Documents, Word Processor, Text Editor, docx, odt, markdown, LibreOffice, Microsoft Word, OpenOffice, Zettlr, Typora, Pandoc'
header-includes: |
    <meta property="og:title" content="Pambda.com: Choose a file format for your writings" />
    <meta property="og:type" content="website" />
    <meta property="og:description" content="For each file format (markdown, docx, odt and html) compatible word processors are compared (Microsoft Word, Zettlr, Open Office, etc)." />
    <meta property="og:url" content="https://pambda.com/Blog/choose-a-file-format-and-a-word-processor-for-your-writings.html" />
    <meta property="og:image" content="https://pambda.com/Blog/choose-a-file-format-and-a-word-processor-for-your-writings/choose-a-format-and-a-word-processor.png" />
    <meta property="og:image:type" content="image/png" />
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="528" />
    <meta property="og:image:alt" content="Pambda" />
    <meta property="og:locale" content="en_US" />
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:image" content="https://pambda.com/Blog/choose-a-file-format-and-a-word-processor-for-your-writings/choose-a-format-and-a-word-processor.png">
    <style>
      li li > p:first-child {margin-top: 0 !important;}
      li li > p:last-child {margin-bottom: 0 !important;}
      /* TODO : https://tympanus.net/codrops/2012/11/02/heading-set-styling-with-css/ */
      /* Inspired by https://css-tricks.com/3-styles-for-big-headers/ */
      h1 {
        font-family: 'Linux Libertine','Georgia','Times',serif;
        font-size: 2.5em;
        letter-spacing: -1px;
      }
      /* Inspired by wikipedia article css*/
      h2 {
        font-size: 1.8em;
        padding: 0;
        font-family: 'Linux Libertine','Georgia','Times',serif;
        line-height: 1.3;
        border-bottom-color: rgb(91, 90, 86);
        border-bottom: 1px solid currentColor;
      }
    </style>
...

# Choose a file format and a word processor for your writings

![Different file formats and corresponding word processors](choose-a-file-format-and-a-word-processor-for-your-writings/choose-a-format-and-a-word-processor.svg "Choose the format of your files and a word processor"){width="50%"}

## Markdown Format

The markdown format is a well-known format in the [STEM](https://en.wikipedia.org/wiki/Science,_technology,_engineering,_and_mathematics) community.
Humanities could greatly benefit from using it too.
In few words, markdown aims to be the lightest format for structured text while preserving multiple formatting capabilities.

> [brief history of the markdown format](https://www.zettlr.com/history)

If you want to learn how to use the markdown format you can read [this brief tutorial](https://learnxinyminutes.com/docs/markdown/).

The basic syntax of markdown files is often extended with new features.
The resulting syntax is called a "flavor" of the markdown syntax.

### Editors

A simple text editor is enough to edit a markdown file, but there are also advanced word processors:

- [Zettlr](https://www.zettlr.com/) is a free software that has a powerful [WYSIWYM](https://en.wikipedia.org/wiki/WYSIWYM) approach and a [pleasant documentation](https://docs.zettlr.com/en/).
- [Typora](https://typora.io/) is a free and neat editor too. However, Typora is somewhat opinionated on the markdown flavor it allows: e.g., the [simple syntax for tables](https://pandoc.org/MANUAL.html#tables) may not be supported well enough.

> Have a look at this [comparison of  Zettlr with other popular Markdown editors](https://www.zettlr.com/features).
> You may also read [this comparison](https://www.slant.co/versus/2813/31650/~typora_vs_zettlr){rel="nofollow"}.

- [Visual Studio Code](https://code.visualstudio.com/) is an open source and free software. Even if Visual Studio Code is mostly known as a programmer software, with the extension [Markdown All in One](https://marketplace.visualstudio.com/items?itemName=yzhang.markdown-all-in-one), it is surprisingly pleasant and efficient to edit markdown files. You can add grammar, style, and spell checking with the LanguageTool extensions -- e.g. [LTex](https://marketplace.visualstudio.com/items?itemName=valentjn.vscode-ltex).

### Markdown flavor and editors used

At Pambda, we use a _pandoc-flavored markdown_, a well-known and well documented markdown variation.
The power of this markdown flavor is showcased in details in [the corresponding sample file](https://input.pambda.com/Documentation/markdown-formatting.md).

We provide guidance with Zettlr and Visual Studio Code for editing markdown files.

![A choice](choose-a-file-format-and-a-word-processor-for-your-writings/selection.svg "Select the appropriate file format for your project"){width="50%"}

## Docx Format

As far as we know docx is the most famous file format for writing structured text.

> Microsoft released the docx format along Microsoft Word 2007. The acronym docx means "*doc* e*x*tension".
> The docx format is officially the successor of the *doc* format, used in previous versions of Microsoft Word, back in 1997.
> It is [often thought](https://en.wikipedia.org/wiki/Office_Open_XML#Standardization_process) that Microsoft created the docx format to protect itself against the odt format -- that was threatening the Microsoft Word monopoly.
> When the docx came out, it was supposed to follow the [OOXML](https://en.wikipedia.org/wiki/Office_Open_XML) norm, but Microsoft diverged from this initial standard to gradually add new features to its docx files.

### Word processors

Docx files are usually edited with the charged and proprietary software, Microsoft Word.
But free editors exist:

- [OpenOffice](https://en.wikipedia.org/wiki/OpenOffice.org) was the first (in time) serious and free competitor to Microsoft Word.
- [LibreOffice](https://en.wikipedia.org/wiki/LibreOffice) is the successor of OpenOffice and [has been recommended](https://sill.etalab.gouv.fr/en/software?id=78) in the French administration for years.

> LibreOffice and OpenOffice deal well with docx files that follow the OOXML norm. Unfortunately the docx of Microsoft keeps diverging from this norm. Thus, if you use either LibreOffice or OpenOffice to open docx files created with Microsoft Word, you may see some quirks when advanced formatting features have been used.

- [OnlyOffice](https://www.onlyoffice.com/) [handles the OOXML norm natively](https://www.onlyoffice.com/blog/2018/08/onlyoffice-vs-libreoffice-what-to-choose-when-you-decide-to-ditch-microsoft) unlike LibreOffice and OpenOffice. Thus, OnlyOffice is theoretically more compatible with docx files created from Microsoft Word. The drawback is that OnlyOffice is also less compatible with odt files created from LibreOffice or OpenOffice.
- [WPS](https://www.wps.com/) is the Chinese competitor of Microsoft Word.
    It is a proprietary software, but free of any charge.

![Fonts](choose-a-file-format-and-a-word-processor-for-your-writings/font.svg "Choose the word processor that will help you write efficiently"){width="50%"}

### Word processor used

At Pambda, we ensure that docx files written with LibreOffice, work well with our services.
During our after-sales services we provide assistance with LibreOffice.
Docx documents, written with Microsoft Word, work well with our service too.

## Odt Format

As part of the [Open Document Formats (ODF)](https://en.wikipedia.org/wiki/OpenDocument), the odt format was created around 2006, just before docx.
The odt format is open source and has been created to ease the exchange of text documents between word processors.
Unfortunately, odt seems still far less used than docx.

### Word processor used

Being open source and stable, most of the word processors support the odt format.
Although some versions of Microsoft Word and OnlyOffice are known for behaving badly with this format.

At Pambda, we provide guidance with LibreOffice to edit odt files.

## Html Format

If you know the HTML markup language, you can write directly into HTML.
This will give you full control over the layout of your writings.
Visual Studio Code works well for editing HTML documents.
