---
title: 'Pambda.com: Manual of the blog'
author: 'Joseph Lucas'
date: '2020-11-10'
description: 'Manual of a blog managed by the static site generator of Pambda services. This manual explains how to write your files to publish new articles.'
keywords: 'Pambda, Pambda.com, static site generator, SSG, static site, CMS, Manual, Documentation, Guide, Tutorial, Howto, Word Processor, Text Editor, docx, odt, markdown, LibreOffice, Microsoft Word, OpenOffice, Pandoc, Workflow'
include-before: |
  <h1>Blog manual</h1>
toc: true
toc-title: 'Table of Contents'
toc-depth: 2
header-includes: |
    <meta property="og:title" content="Pambda.com: Manual of the blog" />
    <meta property="og:type" content="website" />
    <meta property="og:description" content="Manual of a blog managed by the static site generator of Pambda services. This manual explains how to write your files to publish new articles." />
    <meta property="og:url" content="https://pambda.com/Documentation/manual.html" />
    <meta property="og:image" content="https://pambda.com/Documentation/manual/typewriter.png" />
    <meta property="og:image:type" content="image/png" />
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:image:alt" content="Pambda" />
    <meta property="og:locale" content="en_US" />
    <meta name="twitter:card" content="summary\_large\_image">
    <meta name="twitter:image" content="https://pambda.com/Documentation/manual/typewriter.png">
    <style>
      li li > p:first-child {margin-top: 0 !important;}
      li li > p:last-child {margin-bottom: 0 !important;}
      /* TODO : https://tympanus.net/codrops/2012/11/02/heading-set-styling-with-css/ */
      /* Inspired by https://css-tricks.com/3-styles-for-big-headers/ */
      h1 {
        font-family: 'Linux Libertine','Georgia','Times',serif;
        font-size: 2.5em;
        letter-spacing: -1px;
      }
      /* Inspired by wikipedia article css*/
      h2 {
        font-size: 1.8em;
        padding: 0;
        font-family: 'Linux Libertine','Georgia','Times',serif;
        line-height: 1.3;
        border-bottom-color: rgb(91, 90, 86);
        border-bottom: 1px solid currentColor;
      }
      h3 {
        margin-top: 1em;
        font-size: 1.5em;
        margin-bottom: 0.25em;
        padding: 0;
        font-family: 'Linux Libertine','Georgia','Times',serif;
        line-height: 1.3;
        border-bottom: 1px solid currentColor;
      }
      h4 {
        border-bottom: dotted 1px #aaa;
        font-weight: bold;
        font-size: 1.2em;
        margin-top: 0.3em;
        margin-bottom: 0;
        padding-bottom: 0;
        line-height: 1.6;
        padding-top: 0.5em;
      }
      h5 {
        font-weight: bold;
        margin-top: 0.3em;
        margin-bottom: 0;
        padding-bottom: 0;
        line-height: 1.6;
        margin-bottom: 0.3em;
        padding-top: 0.5em;
      }
      h6 {
       margin-top: 0.3em;
       margin-bottom: 0;
       padding-bottom: 0;
       line-height: 1.6;
       padding-top: 0.5em;
      }
      [id='Table of Contents'] {
        display: none;
      }
    </style>
...

## The shared folder

![Filling a folder](manual/filing_folder.svg "The shared folder"){width=50%}

Our service interface is a shared folder (also called "input folder"). 
You are the only one authorized to edit this folder. 
Our service will only read information inside. 
This folder is the one where you will write your files, the configuration of your website theme, etc.

> We manage the installation of the shared folder on your computer with you. 
> If ever it happened that you need to (re)install the shared folder by yourself, the steps are described [here](./manual_shared_folder.md#how-to-mount-the-shared-folder).

This manual explains how to use this folder to edit your blog from your computer.

## How to edit your blog

![A sequence of steps on a computer](manual/workflow.svg "Workflow"){width="50%"}

To add an article in your blog, you just need to add a document (docx, odt, markdowmn, ...) in the folder "Blog" of the shared folder.
The name of the files will determine the URL of the corresponding webpage.

> The shared folder contains folders and files outside the "Blog" folder. They allow you to control other elements of your website. You will find more explanations [here](./manual_shared_folder.md#shared-folder-organisation)

We suggest following the next steps when you edit your blog:

1. Create and edit your files in the shared folder.
2. Once editions are saved, our service automatically triggers an attempt to reconstruct your website.
   If you open a web browser at the URL of your website (e.g., <a rel="nofollow">https://yourwebsite.com</a>), you should see the corresponding modifications.

## Sample files

![Choosing a file](manual/choose-file-format.svg "Choose a file format by looking at the sample files"){width="30%"}

For each file format, the next table gives the correspondence between a file sample (left column) and the webpage computed from this file (right column).
The webpages display supported features of the corresponding file format.

file example                                                                                  corresponding webpage
-----------------------------------------------------------------------------------------     -----------------------------------------
[markdown file](https://input.pambda.com/Documentation/markdown-formatting.md)                [webpage computed from the markdown file](markdown-formatting.html)
[docx file](https://input.pambda.com/Documentation/docx-formatting.docx)                      [webpage computed from the docx file](docx-formatting.html)
[odt file](https://input.pambda.com/Documentation/odt-formatting.odt)                         [webpage computed from the odt file](odt-formatting.html)

You will find detailed instructions on how you should format your files in the files themselves.

> Click on a link in the left column to download the source file.
> Click on the link in the right column to see the corresponding webpage

## Some conventions

You can easily add medias in a page by creating a folder next to the corresponding document — and by naming it with the same name, except the extension. 
This folder will be considered as a way to provide supplementary content, which is very handy. 
But this feature can cause conflicts between folder names. 
To avoid these conflicts, here are some conventions :

- Name documents meant to become web pages with lower-case letters.
- A folder, that hosts medias of a page, must be located next to the corresponding document and is named with the same name; except the extension.
- Name folders that contain documents, by starting their name with a capital letter.

In addition to clarifying the role of each folder, these conventions will ensure that there will be no conflicts between the supplementary folders and the folders that host other documents.

## When problems arise

When the modification is not visible, here is how to investigate

1. Your browser [cache](https://en.wikipedia.org/wiki/Web_cache) may hide the new webpage version.
   In this case, a total refresh bypassing your browser cache — Ctr+F5 — will request a full refresh of the webpage.
2. You can check that your last data have been uploaded properly on the server, by going at <a rel="nofollow">https://input.yourwebsite.com/</a> and by looking at the last modification times.

    > Right now displayed dates have an offset of 1 or 2 hours. (depending on the French time shift in summer/winter)

3. As soon as our service detects new data, it attempts a reconstruction.
   You can check that the reconstruction went well by looking at its log file, viewable at <a rel="nofollow">https://yourwebsite.com/reconstruction.log</a>.
   - If you cannot read the log, there must be a network issue or an error in our server.
   - The reconstruction date should be right after your edition date.
     If it is not the case, it means that there was an error in our service.
   - If the date corresponds, please follow the instructions at the top of the reconstruction log.
4. Read the [FAQ](./faq.html) for guidance on how to solve miscellaneous issues.

![Investigating a software window](manual/investigate.svg "Investigate when something went wrong"){width="50%"}

## Feedback and assistance

After this investigation, if you haven't found/solved the error, please contact us.
Here is what we will do:

1. If there is an error in our service, we will fix.
2. If there is a modification to do in your input folder, we will make a copy of your folder, and we will edit the copy on our side.
   Once we have finished the edition, we will email you with a link to download the edited folder, for instance <a rel="nofollow">https://backup.edited.yourwebsite.com/pambda-input-edited.zip</a>.
   We will also send a link to show how your website looks with our editions: <a rel="nofollow">https://edited.yourwebsite.com</a>.

> For your convenience, we suggest installing [Meld](http://meldmerge.org/). This program will help you to compare the edited folder with your folder.

![visio-conference](manual/dialog.svg "Call us if you haven't found the issue"){width="50%"}

