---
title: 'Pambda.com: Example of webpage created from a markdown file'
author: 'Joseph Lucas'
date: '2022-15-03'
description: 'Example of webpage created from a markdown file. This page shows how markdown can be rendered into html through a static site generator based on pandoc.'
keywords: 'Pambda, Pambda.com, pandoc, markdown, html, website, static site generator, SSG'
include-before: |
  <h1>Example of webpage created from a markdown file</h1>
  <blockquote><p>This page has been calculated from a markdown file. The <a href="https://input.pambda.com/Documentation/markdown-formatting.md">source file</a> shows the basic markdown syntax plus some variations allowed by pandoc.</p></blockquote>
toc: true
toc-depth: 2
toc-title: '(optional) Table of Contents'
header-includes: |
  <script async src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.7/MathJax.js?config=TeX-AMS_SVG"></script>
  <meta property="og:title" content="Pambda.com: Example of webpage created from a markdown file" />
  <meta property="og:type" content="website" />
  <meta property="og:description" content="Example of webpage created from a markdown file. This page shows how markdown can be rendered into html through a static site generator based on pandoc." />
  <meta property="og:url" content="https://pambda.com/Documentation/markdown-formatting.html" />
  <meta property="og:image" content="https://pambda.com/index/logo-social-networks.png" />
  <meta property="og:image:type" content="image/png" />
  <meta property="og:image:width" content="1200" />
  <meta property="og:image:height" content="630" />
  <meta property="og:image:alt" content="Pambda" />
  <meta property="og:locale" content="en_US" />
  <meta name="twitter:card" content="summary\_large\_image">
...

## Inline/Character formatting

You can use several character formats : 

- *italic*
- **bold** 
- [underlined]{.underline}
- supper^script^ 
- sub~script~
- crossed ~~words~~

You can write emojis :smile:

### Links

#### Links to other pages of your site

You can insert links to other pages of your website using relative paths, from the folder of the current file towards the target file: e.g., [a link to the manual](./manual.md) or [a link to the "About" page](../about.md).
Thus links in your file are also valid and allows navigating between your files within your word processor.

#### Links to outside

You can insert links to external web pages, like [www.google.com](https://www.google.com/).
For this you _need_ to write the protocol at the beginning: usually `https://` or `http://`.

You can write emails and phone numbers: 

[john@doe.com](mailto:john@doe.com)\
[(+33).6.12.34.56.78](tel:+33612345678)

#### Link to a section of a webpage

You can insert a link targeting a section of a webpage using `yourwebpage.html#the-section`.
For instance this is [a link to the section named "Inline/Character formatting"](markdown-formatting.html#inlinecharacter-formatting), of this page.

> Here are some ways to find the link to a section :
> (i) Get the link thanks to automatically displayed anchor links. On websites built with our services, an anchor link usually becomes visible when you move your mouse on the title of a section.
>
> ![Anchor link](markdown-formatting/anchor_link.png){style="width:6rem"}
>
> Then make a right-click on the anchor and copy the corresponding link.
> (ii) Second solution, is to copy the link in a table of contents.
> (iii) A last solution is to inspect the source code of the targeted page, looking for a putative "id" of the target.

Be aware that:

- `the-section` must be in lower case, with hyphens (`-`) between words
- all backslashes (`\`) and all simple quotes (`'`) must be removed

### Colors

You can use colors with the [CSS `style` attribute color](https://developer.mozilla.org/en-US/docs/Web/CSS/color): 
e.g., some [coloured]{style="color:red;"} [inline]{style="color:green;"} [text]{style="color:#0000ff;"}.
All available CSS color and color names can be [previewed online](https://www.w3schools.com/colors/colors_names.asp). 
Color definitions can use the hexadecimal format, e.g. [\#0000ff]{style="color:#0000ff;"}.

## Paragraph formatting

### New line and new paragraph

A paragraph is a set of lines that ends with the first empty line.
If you want a new line inside a paragraph, finish the line with a backslash **"\\"**\
After an empty line, it's a new paragraph.

### Paragraphs alignment

::: {style="text-align:left"}
By default, all paragraphs are left-aligned. But you can also enforce a left-alignment yourself, with the paragraph style `text-align:left`.
:::

::: {style="text-align:center"}
A centered paragraph with the paragraph style `text-align:center`.\
This second line belongs to the centered paragraph.\
And this third line is centered too.
:::

::: {style="text-align:justify"}
Here is a justified paragraph, with the paragraph style `text-align:justify`, that does its best to distribute words horizontally between the text borders. Unfortunately, sometimes, this alignment causes big spaces between words of the same line.
:::

::: {style="text-align:right"}
And a right-aligned paragraph with `text-align:right`.
:::

### Notes

> You can write notes

### Lists

bulleted lists,

- first point 
- 2^nd^ point
- ...

numbered lists

1. A
2. B
3. C

and definition lists

Item1
:   description

Item2
:   another description

## Layout formatting

### Columns 

You can write paragraphs in columns.

:::::::::::::: {style="display:flex"}
::: {style="flex: 1 1 50%;padding:0.5rem"}
This is the first column.

Qui nostrud occaecat excepteur enim incididunt anim sit officia laboris aliquip qui aute. Tempor ad labore aute sunt occaecat occaecat sit veniam consequat proident velit Lorem eiusmod non. Quis adipisicing cillum officia laboris mollit aute labore.
:::
::: {style="flex: 1 1 50%;padding:0.5rem"}
and this is the second column.

Officia est do dolore quis nulla ut in duis officia ea ea. Lorem dolore elit proident dolor exercitation veniam excepteur ex incididunt ex. Culpa anim pariatur incididunt ad adipisicing deserunt officia quis consequat exercitation minim. Labore Lorem irure do quis aute occaecat anim eu dolore.
:::
::::::::::::::

### Horizontal separators

You can insert horizontal separators

---------------------

## Insertions

### Media insertion workflow

When you want to insert a media (e.g., a picture, a video, an audio) in your webpage:

1. Create a folder next to your markdown file
2. Rename the folder and give it the name of your markdown file. 

> For instance, given that your markdown file is _i_love_pandas.md_, in this case rename the folder into _i_love_pandas_.

3. Put your media inside the folder: e.g., `panda.png`.
4. In the markdown file, insert the image using `![Description of your image](i_love_pandas/panda.png "A text shown on mouse hover"){ width=25% }`

### Images

#### Bitmap images

You can insert standard ([bitmap or raster](https://en.wikipedia.org/wiki/Raster_graphics)) images (jpeg or png)

![Description of the small panda image](markdown-formatting/image.jpeg "Small panda"){ width=25% }

and control the size of images from the markdown file.

![Description of the big panda image](markdown-formatting/image.jpeg "Big panda"){ width=50% }

#### Vector images

You can insert [vector images](https://en.wikipedia.org/wiki/Vector_graphics) and control their size

![Some vectorial art](markdown-formatting/art.svg "Some vectorial art"){width=min(20em,50%)}

> For vector images, you need to define a size.

#### Animated images

You can insert animated images (GIF) and control their size

![Description of the big panda image](markdown-formatting/animated-panda.gif "Animated panda"){ width=5em }

### Tables

You can insert tables

Table cells         Are             well aligned
--------------  -------------     --------------
col 1 is        left-aligned          A
col 2 is          centered            B
col 3 is        right-aligned         C

### Math equations

You can insert math formulas with the [Latex syntax](https://en.wikipedia.org/wiki/LaTeX): e.g., $x^2 + y^2 = z^2$.

As well as blocks of math equations

$$
x=\frac{-b\pm\sqrt{b^2-4ac}}{2a}
$$

### Raw HTML

Possibilities are endless since you can even write in html inside your file ! 

#### Example of complex html block

You can define columns, insert an image -- animated or not -- from a web URL and control image positions.

```{=html}
<div style="display:flex;text-align:center;">
  <div style="flex: 1 1 50%;align-self: center;">
    You can<br>
    do<br>
    whatever you want<br>
    in raw html<br>
    <a href="https://www.animatedimages.org/cat-pandas-345.htm">
      <img src="https://www.animatedimages.org/data/media/345/animated-panda-image-0011.gif" border="0" alt="A panda dancing" title="A panda dancing" style="width:5em;"/>
    </a>
  </div>
  <div style="--aspect-ratio:16/9;margin:auto;width:100%;flex: 1 1 50%;">
    <img src="markdown-formatting/image.jpeg" alt="A panda resting" title="A panda resting">
  </div>
</div>
```

#### Pdf

You can embed pdf files …

```{=html}
<div style="--aspect-ratio:10/6;width:50%;margin:auto;">
  <object style="width:100%;" type="application/pdf" data="markdown-formatting/simple.pdf#zoom=0&scrollbar=0&toolbar=0&navpanes=0">
      <p>This browser does not support PDFs. Please <a href="https://input.pambda.com/Documentation/markdown-formatting/simple.pdf">download the PDF</a> to view it.</p>
  </object>
</div>
```

… or insert a <a href="https://input.pambda.com/Documentation/markdown-formatting/simple.pdf">link</a> to download the pdf file.

#### Audio

You can play sounds from an uploaded mp3 file

```{=html}
<div style="display:flex; justify-content:center;">
    <audio controls src="markdown-formatting/music.mp3">Your browser does not support the audio element.</audio>
</div>
```

#### Video

You can play a video from an uploaded video file. Either using the WebM encoding (flower.webm) …
<!-- from https://developer.mozilla.org/fr/docs/Web/HTML/Element/video -->
```{=html}
<div style="display:flex; justify-content:center;">
  <video controls="" style="width:50%">
    <source src="markdown-formatting/flower.webm" type="video/webm">
    Sorry, your browser doesn't support embedded videos.
  </video>
</div>
```

… or with the MPEG-4 encoding (beach.mp4)
<!-- from https://filesamples.com/ -->
```{=html}
<div style="display:flex; justify-content:center;">
  <video controls="" style="width:50%">
    <source src="markdown-formatting/beach.mp4" type="video/mp4">
    Sorry, your browser doesn't support embedded videos.
  </video>
</div>
```

#### iframes

You can insert iframes and control their size and their aspect-ratio constraint.

##### Youtube videos


```{=html}
<div style="--aspect-ratio:16/9;width:50%;margin:auto;">
  <iframe src="https://www.youtube.com/embed/nR9eU_tVbxE"></iframe>
</div>
```

##### Google calendars

```{=html}
<div style="--aspect-ratio:16/9;width:75%;margin:auto;">
  <iframe src="https://calendar.google.com/calendar/embed?height=600&amp;wkst=1&amp;bgcolor=%23ffffff&amp;ctz=Europe%2FParis&amp;src=NXA4aTdybWM4amk0cWl0NmsyYWw2dTN1N3MzcGlxOXVAaW1wb3J0LmNhbGVuZGFyLmdvb2dsZS5jb20&amp;src=ZnIuZnJlbmNoI2hvbGlkYXlAZ3JvdXAudi5jYWxlbmRhci5nb29nbGUuY29t&amp;color=%237CB342&amp;color=%230B8043" style="border:solid 1px #777;" frameborder="0" scrolling="no"></iframe>
</div>
```

##### Google maps

```{=html}
<div style="--aspect-ratio:16/9;width:75%;margin:auto;">
  <iframe src="https://www.google.com/maps/embed?pb=!1m14!1m8!1m3!1d10732.596044520616!2d-3.37393523808054!3d47.73976344539741!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x48105e56aa6609ed%3A0xa93367770ccde4ea!2s56100%20Lorient!5e0!3m2!1sen!2sfr!4v1587928272400!5m2!1sen!2sfr" frameborder="0" style="border:0;" allowfullscreen="" aria-hidden="false" tabindex="0"></iframe>
</div>
```

## Webpage metadata

The markdown file format allows to set the metadata of the computed webpage, like the _title_ of the webpage.
This is defined by writing a metadata header at the top of your markdown file, like this: 

```markdown
---
title: 'Pambda.com: Example of webpage created from a markdown file'
author: 'Joseph Lucas'
date: '2020-11-10'
description: 'Example of webpage created from a markdown file'
keywords: 'Pambda, Pambda.com, pandoc, markdown, html, website'
header-includes: |
  <meta property="og:type" content="website" />
  <meta property="og:description" content="Pambda.com: Example of webpage created from a markdown file" />
  <meta property="og:url" content="https://pambda.com/Documentation/markdown-formatting.html" />
  <meta property="og:image" content="https://pambda.com/index/logo-social-networks.png" />
  <meta property="og:image:type" content="image/png" />
  <meta property="og:image:width" content="1200" />
  <meta property="og:image:height" content="630" />
  <meta property="og:image:alt" content="Pambda" />
  <meta property="og:locale" content="en_US" />
  <meta name="twitter:card" content="summary\_large\_image">
...
```
> Be careful, if you use single quotes (`'`) within the value field, then write the values with double quotes (`"`) rather than single quotes.

> Edit the values at the right of "`:`" with the values you want.

Metadata aren't mandatory but they have some utility: 
The _title_ is displayed in the browser tab of the webpage.
The title, the _description_ and _key-words_ helps search engines (like Google) to index your page.
For more information about the long value of the field named "header-includes" see [The Essential Meta Tags for Social Media](https://css-tricks.com/essential-meta-tags-social-media/).

## Table of contents

If you want a table of contents, add this in the metadata block

```markdown
toc: true
toc-title: 'Title of your table of Contents'
toc-depth: 2
```

## Navigation bar

For the navigation bar file `.navbar.md`, use a bulleted list, for instance:

```markdown
- `<a>Lang</a>`{=html}
  - [English](https://pambda.com)
  - [Français](https://pambda.fr)
- [Home](index.html)
- [Services](services.html)
- `<a>Documentation</a>`{=html}
  - [Manual](Documentation/manual.md)
  - [FAQ](Documentation/faq.md)
- [Blog](blog.html)
- [About](about.html)
- [Contact](contact.html)
```
